"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChainTransactionMigrator = void 0;
const ChainTransaction_1 = require("../businessObjects/ChainTransaction");
const EVMTransaction_1 = require("../businessObjects/EVMTransaction");
const SolanaTransaction_1 = require("../businessObjects/SolanaTransaction");
const VersionedObject_1 = require("../businessObjects/VersionedObject");
const configuration_1 = require("../configuration");
const enum_1 = require("../enum");
class ChainTransactionMigrator extends VersionedObject_1.VersionedObjectMigrator {
    getCurrentVersion() {
        return ChainTransaction_1.ChainTransaction.CURRENT_VERSION;
    }
    factory(data) {
        switch ((0, configuration_1.getChainInfoByChainId)(data["chainId"]).chainTechnology) {
            case enum_1.EChainTechnology.Solana:
                return new SolanaTransaction_1.SolanaTransaction(data["ChainId"], data["hash"], data["timestamp"], data["slot"], data["err"], data["memo"]);
            case enum_1.EChainTechnology.EVM:
                return new EVMTransaction_1.EVMTransaction(data["chainId"], data["hash"], data["timestamp"], data["blockHeight"], data["to"], data["from"], data["value"], data["gasPrice"], data["contractAddress"], data["input"], data["methodId"], data["functionName"], data["events"]);
            default:
                throw new Error("chain ID does not match known technology");
        }
    }
    getUpgradeFunctions() {
        return new Map();
    }
}
exports.ChainTransactionMigrator = ChainTransactionMigrator;
//# sourceMappingURL=ChainTransactionMigrator.js.map